@@ -10,33 +10,30 @@
  *
  * Mon Jul  1 18:52:58 1996: janl@math.uio.no (Nicolai Langfeldt):
  *	Incorporated fix by Jonathan Kamens <jik@annex-1-slip-jik.cam.ov.com>
- * 1999-02-22 Arkadiusz Mikiewicz <misiek@misiek.eu.org>
+ * 1999-02-22 Arkadiusz Mikiewicz <misiek@pld.ORG.PL>
  * - added Native Language Support
  *	
  */
 
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
-#include <getopt.h>
-#include <limits.h>
-#include "nls.h"
+#include <nls.h>
 
-#define VERSION		UTIL_LINUX_VERSION
+#include "xalloc.h"
 
 #ifndef DEFAULT_FSTYPE
 # define DEFAULT_FSTYPE		"ext2"
 #endif
 
-#define SEARCH_PATH	"PATH=/sbin:/sbin/fs:/sbin/fs.d:/etc/fs:/etc"
+#define SEARCH_PATH	"PATH=" FS_SEARCH_PATH
 #define PROGNAME	"mkfs.%s"
 
 
 int main(int argc, char *argv[])
 {
-  char progname[NAME_MAX];
+  char *progname;	/* name of executable to be called */
   char *fstype = NULL;
   int i, more = 0, verbose = 0;
   char *oldpath, *newpath;
@@ -52,13 +49,13 @@ int main(int argc, char *argv[])
 
   if (argc == 2 &&
       (!strcmp(argv[1], "-V") || !strcmp(argv[1], "--version"))) {
-	  printf(_("%s from %s\n"), program_name, util_linux_version);
-	  exit(0);
+	  printf(_("%s (%s)\n"), program_name, PACKAGE_STRING);
+	  exit(EXIT_SUCCESS);
   }
 
   /* Check commandline options. */
   opterr = 0;
-  while ((more == 0) && ((i = getopt(argc, argv, "Vt:")) != EOF))
+  while ((more == 0) && ((i = getopt(argc, argv, "Vt:")) != -1))
     switch (i) {
     case 'V':
       verbose++;
@@ -71,11 +68,8 @@ int main(int argc, char *argv[])
       more = 1;
       break;		/* start of specific arguments */
     }
-  if (optind == argc) {
-    fprintf(stderr,
-      _("Usage: mkfs [-V] [-t fstype] [fs-options] device [size]\n"));
-    return -1;
-  }
+  if (optind == argc)
+	  errx(EXIT_FAILURE, _("Usage: mkfs [-V] [-t fstype] [fs-options] device [size]"));
   
   /* If -t wasn't specified, use the default */
   if (fstype == NULL)
@@ -85,18 +79,17 @@ int main(int argc, char *argv[])
   oldpath = getenv("PATH");
   if (!oldpath)
 	  oldpath = "/bin";
-  newpath = (char *) malloc(strlen(oldpath) + sizeof(SEARCH_PATH) + 2);
-  if (!newpath) {
-    fprintf(stderr, _("%s: Out of memory!\n"), "mkfs");
-    exit(1);
-  }
+
+  newpath = xmalloc(strlen(oldpath) + sizeof(SEARCH_PATH) + 3);
   sprintf(newpath, "%s:%s\n", SEARCH_PATH, oldpath);
   putenv(newpath);
-  snprintf(progname, sizeof(progname), PROGNAME, fstype);
+
+  progname = xmalloc(sizeof(PROGNAME) + strlen(fstype) + 1);
+  sprintf(progname, PROGNAME, fstype);
   argv[--optind] = progname;
 
   if (verbose) {
-    printf(_("mkfs version %s (%s)\n"), VERSION, __DATE__);
+    printf(_("mkfs (%s)\n"), PACKAGE_STRING);
     i = optind;
     while (argv[i])
       printf("%s ", argv[i++]);
